Django SVG Select
=================

A Django form widget that allows you to replace a select widget with an SVG file. In order for this to work you need a well formatted SVG file that has elements with ids that match the option values that are in your field.